###########################################################################
#
# RTFPlugin.pm -- plugin for importing Rich Text Format files.
#
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the 
# University of Waikato, New Zealand.
#
# Copyright (C) 2001 New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

package RTFPlugin;

use ConvertBinaryFile;
use strict;
no strict 'refs'; # allow filehandles to be variables and viceversa

sub BEGIN {
    @RTFPlugin::ISA = ('ConvertBinaryFile');
}

my $arguments =
    [ { 'name' => "process_exp",
	'desc' => "{BasePlugin.process_exp}",
	'type' => "regexp",
	'deft' => &get_default_process_exp(),
	'reqd' => "no" },
      { 'name' => "description_tags",
	'desc' => "{HTMLPlugin.description_tags}",
	'type' => "flag" }
];

my $options = { 'name'     => "RTFPlugin",
		'desc'     => "{RTFPlugin.desc}",
		'abstract' => "no",
		'inherits' => "yes",
		'srcreplaceable' => "yes", # Source docs in rtf can be replaced with GS-generated html
		'args'     => $arguments };

sub new {
    my ($class) = shift (@_);
    my ($pluginlist,$inputargs,$hashArgOptLists) = @_;
    push(@$pluginlist, $class);

    push(@{$hashArgOptLists->{"ArgList"}},@{$arguments});
    push(@{$hashArgOptLists->{"OptList"}},$options);
 
    my $self = new ConvertBinaryFile($pluginlist, $inputargs, $hashArgOptLists);

    if ($self->{'info_only'}) {
	# don't worry about any options etc
	return bless $self, $class;
    }

    $self->{'filename_extension'} = "rtf";
    $self->{'file_type'} = "RTF";

    my $secondary_plugin_options = $self->{'secondary_plugin_options'};
    if (!defined $secondary_plugin_options->{'TextPlugin'}) {
	$secondary_plugin_options->{'TextPlugin'} = [];
    }
    if (!defined $secondary_plugin_options->{'HTMLPlugin'}) {
	$secondary_plugin_options->{'HTMLPlugin'} = [];
    }
    my $text_options = $secondary_plugin_options->{'TextPlugin'};
    my $html_options = $secondary_plugin_options->{'HTMLPlugin'};
    
    #$self->{'input_encoding'} = "utf8";
    #$self->{'extract_language'} = 1;
    push(@$text_options, "-input_encoding", "utf8");
    push(@$text_options,"-extract_language") if $self->{'extract_language'};
    push(@$html_options, "-description_tags") if $self->{'description_tags'};
    push(@$html_options,"-extract_language") if $self->{'extract_language'};

    $self = bless $self, $class;

    $self->load_secondary_plugins($class,$secondary_plugin_options, $hashArgOptLists);

    return $self;
}

sub get_default_process_exp {
    my $self = shift (@_);
    return q^(?i)\.rtf$^;
}

1;
